@@ -89,6 +89,7 @@ struct GpmManagerPrivate
 {
 	GpmButton		*button;
 	GSettings		*settings;
+	GSettings		*settings_gsd;
 	GpmDisks		*disks;
 	GpmDpms			*dpms;
 	GpmIdle			*idle;
@@ -370,11 +371,17 @@ gpm_manager_sync_policy_sleep (GpmManager *manager)
 	guint sleep_computer;
 
 	if (!manager->priv->on_battery) {
-		sleep_computer = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_COMPUTER_AC);
-		sleep_display = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_DISPLAY_AC);
+		sleep_computer = g_settings_get_int (manager->priv->settings_gsd, GSD_SETTINGS_SLEEP_COMPUTER_AC);
+		/* hack around new gsettings key */
+		if (!g_settings_get_boolean (manager->priv->settings_gsd, GSD_SETTINGS_SLEEP_COMPUTER_AC_EN))
+			sleep_computer = 0;
+		sleep_display = g_settings_get_int (manager->priv->settings_gsd, GSD_SETTINGS_SLEEP_DISPLAY_AC);
 	} else {
-		sleep_computer = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_COMPUTER_BATT);
-		sleep_display = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SLEEP_DISPLAY_BATT);
+		sleep_computer = g_settings_get_int (manager->priv->settings_gsd, GSD_SETTINGS_SLEEP_COMPUTER_BATT);
+		/* hack around new gsettings key */
+		if (!g_settings_get_boolean (manager->priv->settings_gsd, GSD_SETTINGS_SLEEP_COMPUTER_BATT_EN))
+			sleep_computer = 0;
+		sleep_display = g_settings_get_int (manager->priv->settings_gsd, GSD_SETTINGS_SLEEP_DISPLAY_BATT);
 	}
 
 	/* set the new sleep (inactivity) value */
@@ -747,7 +754,7 @@ gpm_manager_perform_policy (GpmManager  *manager, const gchar *policy_key, const
 	if (gpm_manager_is_inhibit_valid (manager, FALSE, "policy action") == FALSE)
 		return FALSE;
 
-	policy = g_settings_get_enum (manager->priv->settings, policy_key);
+	policy = g_settings_get_enum (manager->priv->settings_gsd, policy_key);
 	g_debug ("action: %s set to %i (%s)", policy_key, policy, reason);
 	if (policy == GPM_ACTION_POLICY_NOTHING) {
 		g_debug ("doing nothing, reason: %s", reason);
@@ -789,9 +796,9 @@ gpm_manager_idle_do_sleep (GpmManager *manager)
 	GpmActionPolicy policy;
 
 	if (!manager->priv->on_battery)
-		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_SLEEP_TYPE_AC);
+		policy = g_settings_get_enum (manager->priv->settings_gsd, GSD_SETTINGS_ACTION_SLEEP_TYPE_AC);
 	else
-		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_SLEEP_TYPE_BATT);
+		policy = g_settings_get_enum (manager->priv->settings_gsd, GSD_SETTINGS_ACTION_SLEEP_TYPE_BATT);
 
 	if (policy == GPM_ACTION_POLICY_NOTHING) {
 		g_debug ("doing nothing as system idle action");
@@ -906,13 +913,13 @@ gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 
 	if (!manager->priv->on_battery) {
 		g_debug ("Performing AC policy");
-		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_AC,
+		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_AC,
 					    "Lid closed on AC power.");
 		return;
 	}
 
 	g_debug ("Performing battery policy");
-	gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_BATT,
+	gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_BATT,
 				    "Lid closed on battery power.");
 }
 
@@ -995,13 +1002,13 @@ gpm_manager_button_pressed_cb (GpmButton *button, const gchar *type, GpmManager
 	}
 
 	if (g_strcmp0 (type, GPM_BUTTON_POWER) == 0) {
-		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_POWER, "The power button has been pressed.");
+		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_POWER, "The power button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_SLEEP) == 0) {
-		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
+		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_SUSPEND) == 0) {
-		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
+		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_SUSPEND, "The suspend button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_HIBERNATE) == 0) {
-		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_HIBERNATE, "The hibernate button has been pressed.");
+		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_HIBERNATE, "The hibernate button has been pressed.");
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_OPEN) == 0) {
 		gpm_manager_lid_button_pressed (manager, FALSE);
 	} else if (g_strcmp0 (type, GPM_BUTTON_LID_CLOSED) == 0) {
@@ -1057,7 +1064,6 @@ gpm_manager_get_spindown_timeout (GpmManager *manager)
 static void
 gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
 {
-	gboolean event_when_closed;
 	gint timeout;
 	gboolean on_battery;
 	gboolean lid_is_closed;
@@ -1113,17 +1119,12 @@ gpm_manager_client_changed_cb (UpClient *client, GpmManager *manager)
 	else
 		gpm_manager_play (manager, GPM_MANAGER_SOUND_POWER_UNPLUG, FALSE);
 
-	/* We do the lid close on battery action if the ac adapter is removed
-	   when the laptop is closed and on battery. Fixes #331655 */
-	event_when_closed = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_SLEEP_WHEN_CLOSED);
-
 	/* We keep track of the lid state so we can do the
-	   lid close on battery action if the ac adapter is removed when the laptop
-	   is closed. Fixes #331655 */
-	if (event_when_closed && on_battery && lid_is_closed) {
-		gpm_manager_perform_policy (manager, GPM_SETTINGS_BUTTON_LID_BATT,
-					    "The lid has been closed, and the ac adapter "
-					    "removed (and GSettings is okay).");
+	 * lid close on battery action if the ac adapter is removed when the laptop
+	 * is closed */
+	if (on_battery && lid_is_closed) {
+		gpm_manager_perform_policy (manager, GSD_SETTINGS_BUTTON_LID_BATT,
+					    "The lid has been closed, and the ac adapter removed.");
 	}
 }
 
@@ -1143,7 +1144,7 @@ manager_critical_action_do (GpmManager *manager)
 	if (manager->priv->critical_alert_timeout_id)
 		gpm_manager_play_loop_stop (manager);
 
-	gpm_manager_perform_policy (manager, GPM_SETTINGS_ACTION_CRITICAL_BATT, "Battery is critically low.");
+	gpm_manager_perform_policy (manager, GSD_SETTINGS_ACTION_CRITICAL_BATT, "Battery is critically low.");
 	return FALSE;
 }
 
@@ -1167,10 +1168,12 @@ gpm_manager_class_init (GpmManagerClass *klass)
 static void
 gpm_manager_settings_changed_cb (GSettings *settings, const gchar *key, GpmManager *manager)
 {
-	if (g_strcmp0 (key, GPM_SETTINGS_SLEEP_COMPUTER_BATT) == 0 ||
-	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_COMPUTER_AC) == 0 ||
-	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
-	    g_strcmp0 (key, GPM_SETTINGS_SLEEP_DISPLAY_AC) == 0)
+	if (g_strcmp0 (key, GSD_SETTINGS_SLEEP_COMPUTER_BATT) == 0 ||
+	    g_strcmp0 (key, GSD_SETTINGS_SLEEP_COMPUTER_AC) == 0 ||
+	    g_strcmp0 (key, GSD_SETTINGS_SLEEP_COMPUTER_BATT_EN) == 0 ||
+	    g_strcmp0 (key, GSD_SETTINGS_SLEEP_COMPUTER_AC_EN) == 0 ||
+	    g_strcmp0 (key, GSD_SETTINGS_SLEEP_DISPLAY_BATT) == 0 ||
+	    g_strcmp0 (key, GSD_SETTINGS_SLEEP_DISPLAY_AC) == 0)
 		gpm_manager_sync_policy_sleep (manager);
 }
 
@@ -1702,7 +1705,7 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, UpDevice *device, GpmM
 		}
 
 		/* we have to do different warnings depending on the policy */
-		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_BATT);
+		policy = g_settings_get_enum (manager->priv->settings_gsd, GSD_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1858,7 +1861,7 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 		title = _("Laptop battery critically low");
 
 		/* we have to do different warnings depending on the policy */
-		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_BATT);
+		policy = g_settings_get_enum (manager->priv->settings_gsd, GSD_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1894,7 +1897,7 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, UpDevice *device, GpmMan
 		title = _("UPS critically low");
 
 		/* we have to do different warnings depending on the policy */
-		policy = g_settings_get_enum (manager->priv->settings, GPM_SETTINGS_ACTION_CRITICAL_UPS);
+		policy = g_settings_get_enum (manager->priv->settings_gsd, GSD_SETTINGS_ACTION_CRITICAL_BATT);
 
 		/* use different text for different actions */
 		if (policy == GPM_ACTION_POLICY_NOTHING) {
@@ -1998,15 +2001,17 @@ gpm_manager_control_resume_cb (GpmControl *control, GpmControlAction action, Gpm
 static GVariant *
 gpm_manager_device_to_variant_blob (UpDevice *device)
 {
-	gchar *display = NULL;
 	UpDeviceKind kind;
 	UpDeviceState state;
 	gdouble percentage;
 	guint64 time_state = 0;
 	guint64 time_empty, time_full;
 	GVariant *value;
+	GIcon *icon;
+	gchar *device_icon;
 
-	display = gpm_upower_get_device_summary (device);
+	icon = gpm_upower_get_device_icon (device, FALSE);
+	device_icon = g_icon_to_string (icon);
 	g_object_get (device,
 		      "kind", &kind,
 		      "percentage", &percentage,
@@ -2025,11 +2030,11 @@ gpm_manager_device_to_variant_blob (UpDevice *device)
 	value = g_variant_new ("(susdut)",
 			       up_device_get_object_path (device),
 			       kind,
-			       display,
+			       device_icon,
 			       percentage,
 			       state,
 			       time_state);
-	g_free (display);
+	g_free (device_icon);
 	return value;
 }
 
@@ -2214,9 +2219,7 @@ gpm_manager_name_lost_cb (GDBusConnection *connection,
 static void
 gpm_manager_init (GpmManager *manager)
 {
-	gboolean check_type_cpu;
 	gint timeout;
-	guint version;
 
 	manager->priv = GPM_MANAGER_GET_PRIVATE (manager);
 
@@ -2242,6 +2245,9 @@ gpm_manager_init (GpmManager *manager)
 	manager->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 	g_signal_connect (manager->priv->settings, "changed",
 			  G_CALLBACK (gpm_manager_settings_changed_cb), manager);
+	manager->priv->settings_gsd = g_settings_new (GSD_SETTINGS_SCHEMA);
+	g_signal_connect (manager->priv->settings_gsd, "changed",
+			  G_CALLBACK (gpm_manager_settings_changed_cb), manager);
 	manager->priv->client = up_client_new ();
 	g_signal_connect (manager->priv->client, "changed",
 			  G_CALLBACK (gpm_manager_client_changed_cb), manager);
@@ -2249,21 +2255,6 @@ gpm_manager_init (GpmManager *manager)
 	/* use libnotify */
 	notify_init (GPM_NAME);
 
-	/* check to see if the user has installed the schema properly */
-	version = g_settings_get_int (manager->priv->settings, GPM_SETTINGS_SCHEMA_VERSION);
-	if (version != GPM_SETTINGS_SCHEMA_ID) {
-		gpm_manager_notify (manager, &manager->priv->notification_general,
-				    /* TRANSLATORS: there was in install problem */
-				    _("Install problem!"),
-				    /* TRANSLATORS: the GConf schema was not installed properly */
-				    _("The configuration defaults for GNOME Power Manager have not been installed correctly.\n"
-				      "Please contact your computer administrator."),
-				    GPM_MANAGER_NOTIFY_TIMEOUT_LONG,
-				    GTK_STOCK_DIALOG_WARNING,
-				    NOTIFY_URGENCY_NORMAL);
-		g_error ("no GSettings schema installed!");
-	}
-
 	/* coldplug so we are in the correct state at startup */
 	g_object_get (manager->priv->client,
 		      "on-battery", &manager->priv->on_battery,
@@ -2283,10 +2274,6 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->idle, "idle-changed",
 			  G_CALLBACK (gpm_manager_idle_changed_cb), manager);
 
-	/* set up the check_type_cpu, so we can disable the CPU load check */
-	check_type_cpu = g_settings_get_boolean (manager->priv->settings, GPM_SETTINGS_IDLE_CHECK_CPU);
-	gpm_idle_set_check_cpu (manager->priv->idle, check_type_cpu);
-
 	manager->priv->dpms = gpm_dpms_new ();
 	g_signal_connect (manager->priv->dpms, "mode-changed",
 			  G_CALLBACK (gpm_manager_dpms_mode_changed_cb), manager);
@@ -2378,6 +2365,7 @@ gpm_manager_finalize (GObject *object)
 		g_source_remove (manager->priv->critical_alert_timeout_id);
 
 	g_object_unref (manager->priv->settings);
+	g_object_unref (manager->priv->settings_gsd);
 	g_object_unref (manager->priv->disks);
 	g_object_unref (manager->priv->dpms);
 	g_object_unref (manager->priv->idle);
